==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Widgets/SelectionDisplay/ts/SelectionDisplay_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>SelectionDisplay</name>
    <message>
        <source>No selected entities.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">Nenhuma entidade foi selecionada.</translation>
    </message>
    <message>
        <location filename="../SelectionDisplay.js" line="+58"/>
        <source>No entities selected.</source>
        <translation>Nenhuma entidade foi selecionada.</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>%1 %2 on Layer &apos;%3&apos;</source>
        <translation>%1 %2 na camada &apos;%3&apos;</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>%1 %2 on %3 Layers</source>
        <translation>%1 %2 em %3 Camadas</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>%1 Entities on Layer &apos;%2&apos;</source>
        <translation>%1 Entidades na Camada &apos;%2&apos;</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>%1 Entities on %2 Layers</source>
        <translation>%1 Entidades em %2 Camadas</translation>
    </message>
    <message>
        <source>Entities</source>
        <translatorcomment>--google--
Crie um novo carimbo a partir de entidades existentes
Desselecione todas as Entidades</translatorcomment>
        <translation type="vanished">Entidades</translation>
    </message>
    <message>
        <source> on </source>
        <translatorcomment>--google--
Foca na &amp;Linha de Comando
Foca na Linha de Comando
Ponto de corte não está na entidade.</translatorcomment>
        <translation type="obsolete">em</translation>
    </message>
    <message>
        <source>on</source>
        <translation type="vanished">em</translation>
    </message>
    <message>
        <source>Layer &apos;%1&apos;</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">Camada &apos;%1&apos;</translation>
    </message>
    <message>
        <source>%1 Layers</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">%1 Camadas</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Selected entities:
%1.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Entidades selecionadas:
%1</translation>
    </message>
    <message>
        <location filename="../SelectionDisplay.ui" line="+26"/>
        <source>Form</source>
        <translation>Formulário</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Widgets/SelectionDisplay/ts/SelectionDisplay_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>SelectionDisplay</name>
    <message>
        <source>No selected entities.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">Nenhuma entidade foi selecionada.</translation>
    </message>
    <message>
        <location filename="../SelectionDisplay.js" line="+58"/>
        <source>No entities selected.</source>
        <translation>Nenhuma entidade foi selecionada.</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>%1 %2 on Layer &apos;%3&apos;</source>
        <translation>%1 %2 na camada &apos;%3&apos;</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>%1 %2 on %3 Layers</source>
        <translation>%1 %2 em %3 Camadas</translation>
    </message>
    <message numerus="yes">
        <location line="+4"/>
        <source>%n Entities on Layer &apos;%1&apos;</source>
        <translation>
            <numerusform>%n entidad na camada &apos;%1&apos;</numerusform>
            <numerusform>%n entidades na camada &apos;%1&apos;</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+3"/>
        <source>%n Entities</source>
        <translation>
            <numerusform>%n entidad</numerusform>
            <numerusform>%n entidades</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+0"/>
        <source>%n Layers</source>
        <translation>
            <numerusform>%n camada</numerusform>
            <numerusform>%n camadas</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 Entities on Layer &apos;%2&apos;</source>
        <translation type="vanished">%1 Entidades na Camada &apos;%2&apos;</translation>
    </message>
    <message>
        <source>%1 Entities on %2 Layers</source>
        <translation type="vanished">%1 Entidades em %2 Camadas</translation>
    </message>
    <message>
        <source>Entities</source>
        <translatorcomment>--google--
Crie um novo carimbo a partir de entidades existentes
Desselecione todas as Entidades</translatorcomment>
        <translation type="vanished">Entidades</translation>
    </message>
    <message>
        <source> on </source>
        <translatorcomment>--google--
Foca na &amp;Linha de Comando
Foca na Linha de Comando
Ponto de corte não está na entidade.</translatorcomment>
        <translation type="obsolete">em</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>on</source>
        <translation>em</translation>
    </message>
    <message>
        <source>Layer &apos;%1&apos;</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">Camada &apos;%1&apos;</translation>
    </message>
    <message>
        <source>%1 Layers</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">%1 Camadas</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Selected entities:
%1.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Entidades selecionadas:
%1</translation>
    </message>
    <message>
        <location filename="../SelectionDisplay.ui" line="+26"/>
        <source>Form</source>
        <translation>Formulário</translation>
    </message>
</context>
</TS>
